package com.jz.dmp.modules.service.impl;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.jz.agent.service.DmpDsAgentService;
import com.jz.common.constant.JsonResult;
import com.jz.common.constant.ResultCode;
import com.jz.common.page.PageInfoResponse;
import com.jz.common.persistence.BaseService;
import com.jz.common.utils.JsonMapper;
import com.jz.dmp.agent.DmpAgentResult;
import com.jz.dmp.modules.controller.DataIntegration.bean.SourceDbNameListDto;
import com.jz.dmp.modules.controller.DataIntegration.bean.TaskListPageDto;
import com.jz.dmp.modules.controller.DataIntegration.bean.TaskListPageReq;
import com.jz.dmp.modules.dao.DmpProjectDao;
import com.jz.dmp.modules.dao.OfflineSynchDao;
import com.jz.dmp.modules.model.DmpAgentDatasourceInfo;
import com.jz.dmp.modules.service.OfflineSynchService;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Description:离线同步服务层
 * @ClassName: OfflineSynchServiceImpl
 * @Author Bellamy
 * @Date 2020/12/20
 */

@Service("offlineSynchService")
@Transactional
public class OfflineSynchServiceImpl implements OfflineSynchService {

    @Value("${spring.public-key}")
    private String publicKey;

    @Autowired
    private OfflineSynchDao offlineSynchDao;

    @Autowired
    private DmpProjectDao dmpProjectDao;

    @Autowired
    private DmpDsAgentService dmpDsAgentServiceImp;

    @Override
    public PageInfoResponse<TaskListPageDto> queryTaskListPage(TaskListPageReq taskListPageReq) throws Exception {
        PageInfoResponse<TaskListPageDto> pageInfoResponse = new PageInfoResponse<>();

        Map param = new HashMap();
        //param.put("userId", user.getUserId());
        //param.put("pageNum", pageBean.getPageNum());
        //param.put("pageSize", pageBean.getPageSize());
        PageHelper.startPage(taskListPageReq.getPageNum(), taskListPageReq.getPageSize());
        List<TaskListPageDto> list = offlineSynchDao.queryTaskListPage(taskListPageReq);
        PageInfo<TaskListPageDto> pageInfo = new PageInfo<>(list);

        pageInfoResponse.setCode(ResultCode.SUCCESS);
        pageInfoResponse.setMessage("查询成功");
        pageInfoResponse.setData(pageInfo);
        return pageInfoResponse;
    }

    @Override
    public JsonResult<List<SourceDbNameListDto>> querygSourceDbList(Integer projectId) throws Exception {
        Map map = new HashMap();
        map.put("projectId", projectId); //项目id
        map.put("isEnableSource", "1");
        List<SourceDbNameListDto> list = offlineSynchDao.querygSourceDbList(map);
        return new JsonResult(ResultCode.SUCCESS, list);
    }

    @Override
    public JsonResult querygSourceTableList(Integer sourceDbId, String targetName) throws Exception {
        //通过源数据库id ，查询数据源配置
        DmpAgentDatasourceInfo dsInfo = offlineSynchDao.querySourceDbInfoBySourceId(sourceDbId);
        //解码数据库密码
        if (StringUtils.isNotBlank(dsInfo.getPassword())) {
            dsInfo.setPassword(new BaseService().decode(dsInfo.getPassword(), publicKey));
        }
        if (StringUtils.isNotBlank(targetName)) {
            dsInfo.setTargetFileName(targetName);
        }
        DmpAgentResult rst = dmpDsAgentServiceImp.getTableNameList(dsInfo);
        if (!rst.getCode().val().equals("200")) {
            return new JsonResult(rst.getCode(), rst.getMessage());
        } else {
            rst.setResult(JsonMapper.fromJsonString(rst.getMessage(), List.class));
            return new JsonResult(ResultCode.SUCCESS, rst);
        }
    }

}
